@@ -19,7 +19,7 @@ from django.views.debug import ExceptionReporter
 
 from sentry import conf
 from sentry.helpers import construct_checksum, varmap, transform, get_installed_apps, urlread, force_unicode, \
-                           get_versions
+                           get_versions, shorten
 
 logger = logging.getLogger('sentry.errors')
 
@@ -65,6 +65,12 @@ class SentryClient(object):
         versions = get_versions()
         kwargs['data']['__sentry__']['versions'] = versions
 
+        # Shorten lists/strings
+        for k, v in kwargs['data'].iteritems():
+            if k == '__sentry__':
+                continue
+            kwargs['data'][k] = shorten(v)
+
         if kwargs.get('view'):
             # get list of modules from right to left
             parts = kwargs['view'].split('.')
@@ -210,12 +216,6 @@ class SentryClient(object):
 
         exc_type, exc_value, exc_traceback = exc_info
 
-        def shorten(var):
-            var = transform(var)
-            if isinstance(var, basestring) and len(var) > 200:
-                var = var[:200] + '...'
-            return var
-
         reporter = ExceptionReporter(None, exc_type, exc_value, exc_traceback)
         frames = varmap(shorten, reporter.get_traceback_frames())
 
