@@ -15,6 +15,7 @@ from django.http import HttpResponse, HttpResponseBadRequest, \
 from django.shortcuts import get_object_or_404
 from django.template.loader import render_to_string
 from django.utils import simplejson
+from django.utils.encoding import smart_str
 from django.utils.safestring import mark_safe
 from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
@@ -367,10 +368,9 @@ def store(request):
             data = base64.b64decode(data)
     except Exception, e:
         # This error should be caught as it suggests that there's a
-        # bug somewhere in the Sentry code.
+        # bug somewhere in the client's code.
         logger.exception('Bad data received')
-        return HttpResponseForbidden('Bad data')
-
+        return HttpResponseForbidden('Bad data decoding request (%s, %s)' % (e.__class__.__name__, e))
     try:
         if format == 'pickle':
             data = pickle.loads(data)
@@ -378,9 +378,12 @@ def store(request):
             data = simplejson.loads(data)
     except Exception, e:
         # This error should be caught as it suggests that there's a
-        # bug somewhere in the Sentry code.
+        # bug somewhere in the client's code.
         logger.exception('Bad data received')
-        return HttpResponseForbidden('Bad data')
+        return HttpResponseForbidden('Bad data reconstructing object (%s, %s)' % (e.__class__.__name__, e))
+
+    # XXX: ensure keys are coerced to strings
+    data = dict((smart_str(k), v) for k, v in data.iteritems())
 
     GroupedMessage.objects.from_kwargs(**data)
     
@@ -443,4 +446,4 @@ def static_media(request, path):
     response = HttpResponse(contents, mimetype=mimetype)
     response["Last-Modified"] = http_date(statobj[stat.ST_MTIME])
     response["Content-Length"] = len(contents)
-    return response
\ No newline at end of file
+    return response
